Module: FriendlyId::Scoped::Configuration
- Defined in:
- lib/friendly_id/scoped.rb
Overview
This module adds the ‘:scope` configuration option to FriendlyId::Configuration.
Instance Attribute Summary collapse
-
#scope ⇒ Object
Gets the scope value.
Instance Method Summary collapse
-
#scope_columns ⇒ Object
Gets the scope columns.
Instance Attribute Details
#scope ⇒ Object
Gets the scope value.
When setting this value, the argument should be a symbol referencing a ‘belongs_to` relation, or a column.
153 154 155 |
# File 'lib/friendly_id/scoped.rb', line 153 def scope @scope end |
Instance Method Details
#scope_columns ⇒ Object
Gets the scope columns.
Checks to see if the ‘:scope` option passed to Base#friendly_id refers to a relation, and if so, returns the realtion’s foreign key. Otherwise it assumes the option value was the name of column and returns it cast to a String.
163 164 165 |
# File 'lib/friendly_id/scoped.rb', line 163 def scope_columns [@scope].flatten.map { |s| (reflection_foreign_key(s) or s).to_s } end |